// This template is for creating a Strategy that accesses MWaveChart

/*
Function Definitions

// Returns Wave Total Volume at index i
double getVolume(int i)

// Returns Wave Bid Volume at index i
double getBidVolume(int i)

// Returns Wave Ask Volume at index i
double getAskVolume(int i)

// Returns Wave Delta Volume at index i
double getDeltaVolume(int i)

// Returns Wave Delta Percent at index i
double getDeltaPercent(int i)

// Returns Wave Length at index i
double getLength(int i)

// Returns Wave Time index i
double getTime(int i)

//  Returns Wave Width Volume at index i
int getWidth(int i)

//  Returns if swing end point occurred at index i
//  1 if up swing end point
// -1 if down swing end point
//  0 if not an end point
int getSwing(int i)

//  The following functions return if algorithmic signal occured at index i
//  1 on up swing, -1 on down swing, 2 on up swing with trend, -2 on down swing with trend
int getStoogesVolume(int i)

//  1 on up swing, -1 on down swing, 2 on up swing with trend, -2 on down swing with trend
int getStoogesDelta(int i)

//  1 on up swing, -1 on down swing, 2 on up swing with trend, -2 on down swing with trend
int getPullbacks(int i)

//  1 on up swing, -1 on down swing
int getSpringsUpthrusts(int i)

*/

// NOTE: This strategy can be used to simulate MBoxHistogram
// by setting SwingBase to LastClose and Reversal Amount to 0


namespace NinjaTrader.NinjaScript.Strategies
{
	public class MApiMWaveChartStrategy : Strategy
	{
		Indicators.MBoxWaveXE.MWaveChart myWave;

		protected override void OnStateChange()
		{
			// Initialize myWave using MWaveChart
			initMWaveChart
			(	
				// Reference to myWave
				ref myWave,

				// SwingBase: FirstClose, LastClose, HighLow
				SwingBase.FirstClose,
				
				// Calculation Mode: Ticks, Percent
				CalculationMode1.Ticks,
				
				// Reversal amount: Enter an integer
				3,
				
				// Compute Algorithmic Signals: None, All
				AlgoSelected.All,
				
				// Algo Filter: None, Smart, TrendFollowing, Countertrend};
				AlgoFilter.Smart,
				
				// Delta Type (Choose only one, comment the rest)
				DeltaTypeEnum.MBoxPrecisionDelta
				//DeltaTypeEnum.BidAsk
				//DeltaTypeEnum.UpDownTick
				//DeltaTypeEnum.Psuedo
			);

			if (State == State.SetDefaults)
				Calculate = Calculate.OnEachTick;
		}

		protected override void OnBarUpdate()
		{
			// Only process main data series
			if (BarsInProgress != 0) return;
			
			// Wait for at least 100 bars before doing anything
			if (CurrentBar < 100) return;
			
			// This is required to sync with our indicator instance
			myWave.Update();
			
			// Get Wave Swing Index for last 5 waves
			int SI0 = 0;
			int SI1 = SI0 + myWave.getWidth(SI0);
			int SI2 = SI1 + myWave.getWidth(SI1);
			int SI3 = SI2 + myWave.getWidth(SI2);
			int SI4 = SI3 + myWave.getWidth(SI3);
			
			// Get Wave Direction for last 5 waves
			int WD0 = myWave.getSwing(SI1) * -1;
			int WD1 = myWave.getSwing(SI1);
			int WD2 = myWave.getSwing(SI2);
			int WD3 = myWave.getSwing(SI3);
			int WD4 = myWave.getSwing(SI4);

			// Get Total Wave Volume for last 5 waves
			double TV0 = myWave.getVolume(SI0);
			double TV1 = myWave.getVolume(SI1);
			double TV2 = myWave.getVolume(SI2);
			double TV3 = myWave.getVolume(SI3);
			double TV4 = myWave.getVolume(SI4);
			
			// Get Delta Wave Volume for last 5 waves
			double DV0 = myWave.getDeltaVolume(SI0);
			double DV1 = myWave.getDeltaVolume(SI1);
			double DV2 = myWave.getDeltaVolume(SI2);
			double DV3 = myWave.getDeltaVolume(SI3);
			double DV4 = myWave.getDeltaVolume(SI4);
			
			
			Print("###### WAVE 0 ######");
			Print("Direction: "    + WD0);
			//Print("Total Volume: " + TV0);
			Print("Delta Volume: " + DV0);
			
			Print("###### WAVE 1 ######");
			Print("Direction: "    + WD1);
			//Print("Total Volume: " + TV1);
			Print("Delta Volume: " + DV1);
			
			Print("###### WAVE 2 ######");
			Print("Direction: "    + WD2);
			//Print("Total Volume: " + TV2);
			Print("Delta Volume: " + DV2);
			
			Print("###### WAVE 3 ######");
			Print("Direction: "    + WD3);
			//Print("Total Volume: " + TV3);
			Print("Delta Volume: " + DV3);
			
			Print("###### WAVE 4 ######");
			Print("Direction: "    + WD4);
			//Print("Total Volume: " + TV4);
			Print("Delta Volume: " + DV4);
		}
	}
}

